@@ -1,7 +1,7 @@
 package Org::Element;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2016-03-24'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010;
 use locale;
@@ -68,12 +68,13 @@ sub next_sibling {
 sub extra_walkables { return () }
 
 sub walk {
-    my ($self, $code) = @_;
-    $code->($self);
+    my ($self, $code, $_level) = @_;
+    $_level //= 0;
+    $code->($self, $_level);
     if ($self->children) {
-        $_->walk($code) for @{$self->children};
+        $_->walk($code, $_level+1) for @{$self->children};
     }
-    $_->walk($code) for $self->extra_walkables;
+    $_->walk($code, $_level+1) for $self->extra_walkables;
 }
 
 sub find {
@@ -179,7 +180,7 @@ Org::Element - Base class for Org document elements
 
 =head1 VERSION
 
-This document describes version 0.45 of Org::Element (from Perl distribution Org-Parser), released on 2015-08-18.
+This document describes version 0.46 of Org::Element (from Perl distribution Org-Parser), released on 2016-03-24.
 
 =head1 SYNOPSIS
 
@@ -292,7 +293,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
